==> android-test-4.0.1.2-sources.jar: android/test/TouchUtils.java <==
package android.test;
public class TouchUtils
{
public  TouchUtils() { throw new RuntimeException("Stub!"); }
public static  void dragQuarterScreenDown(android.test.ActivityInstrumentationTestCase test) { throw new RuntimeException("Stub!"); }
public static  void dragQuarterScreenDown(android.test.InstrumentationTestCase test, android.app.Activity activity) { throw new RuntimeException("Stub!"); }
public static  void dragQuarterScreenUp(android.test.ActivityInstrumentationTestCase test) { throw new RuntimeException("Stub!"); }
public static  void dragQuarterScreenUp(android.test.InstrumentationTestCase test, android.app.Activity activity) { throw new RuntimeException("Stub!"); }
public static  void scrollToBottom(android.test.ActivityInstrumentationTestCase test, android.view.ViewGroup v) { throw new RuntimeException("Stub!"); }
public static  void scrollToBottom(android.test.InstrumentationTestCase test, android.app.Activity activity, android.view.ViewGroup v) { throw new RuntimeException("Stub!"); }
public static  void scrollToTop(android.test.ActivityInstrumentationTestCase test, android.view.ViewGroup v) { throw new RuntimeException("Stub!"); }
public static  void scrollToTop(android.test.InstrumentationTestCase test, android.app.Activity activity, android.view.ViewGroup v) { throw new RuntimeException("Stub!"); }
public static  void dragViewToBottom(android.test.ActivityInstrumentationTestCase test, android.view.View v) { throw new RuntimeException("Stub!"); }
public static  void dragViewToBottom(android.test.InstrumentationTestCase test, android.app.Activity activity, android.view.View v) { throw new RuntimeException("Stub!"); }
public static  void dragViewToBottom(android.test.ActivityInstrumentationTestCase test, android.view.View v, int stepCount) { throw new RuntimeException("Stub!"); }
public static  void dragViewToBottom(android.test.InstrumentationTestCase test, android.app.Activity activity, android.view.View v, int stepCount) { throw new RuntimeException("Stub!"); }
public static  void tapView(android.test.InstrumentationTestCase test, android.view.View v) { throw new RuntimeException("Stub!"); }
public static  void touchAndCancelView(android.test.InstrumentationTestCase test, android.view.View v) { throw new RuntimeException("Stub!"); }
public static  void clickView(android.test.InstrumentationTestCase test, android.view.View v) { throw new RuntimeException("Stub!"); }
public static  void longClickView(android.test.ActivityInstrumentationTestCase test, android.view.View v) { throw new RuntimeException("Stub!"); }
public static  void longClickView(android.test.InstrumentationTestCase test, android.view.View v) { throw new RuntimeException("Stub!"); }
public static  void dragViewToTop(android.test.ActivityInstrumentationTestCase test, android.view.View v) { throw new RuntimeException("Stub!"); }
public static  void dragViewToTop(android.test.ActivityInstrumentationTestCase test, android.view.View v, int stepCount) { throw new RuntimeException("Stub!"); }
public static  void dragViewToTop(android.test.InstrumentationTestCase test, android.view.View v) { throw new RuntimeException("Stub!"); }
public static  void dragViewToTop(android.test.InstrumentationTestCase test, android.view.View v, int stepCount) { throw new RuntimeException("Stub!"); }
public static  int dragViewBy(android.test.ActivityInstrumentationTestCase test, android.view.View v, int gravity, int deltaX, int deltaY) { throw new RuntimeException("Stub!"); }
public static  int dragViewBy(android.test.InstrumentationTestCase test, android.view.View v, int gravity, int deltaX, int deltaY) { throw new RuntimeException("Stub!"); }
public static  int dragViewTo(android.test.ActivityInstrumentationTestCase test, android.view.View v, int gravity, int toX, int toY) { throw new RuntimeException("Stub!"); }
public static  int dragViewTo(android.test.InstrumentationTestCase test, android.view.View v, int gravity, int toX, int toY) { throw new RuntimeException("Stub!"); }
public static  int dragViewToX(android.test.ActivityInstrumentationTestCase test, android.view.View v, int gravity, int toX) { throw new RuntimeException("Stub!"); }
public static  int dragViewToX(android.test.InstrumentationTestCase test, android.view.View v, int gravity, int toX) { throw new RuntimeException("Stub!"); }
public static  int dragViewToY(android.test.ActivityInstrumentationTestCase test, android.view.View v, int gravity, int toY) { throw new RuntimeException("Stub!"); }
public static  int dragViewToY(android.test.InstrumentationTestCase test, android.view.View v, int gravity, int toY) { throw new RuntimeException("Stub!"); }
public static  void drag(android.test.ActivityInstrumentationTestCase test, float fromX, float toX, float fromY, float toY, int stepCount) { throw new RuntimeException("Stub!"); }
public static  void drag(android.test.InstrumentationTestCase test, float fromX, float toX, float fromY, float toY, int stepCount) { throw new RuntimeException("Stub!"); }
}

==> android-test-4.1.1.4-sources.jar: android/test/TouchUtils.java <==
package android.test;
public class TouchUtils
{
public  TouchUtils() { throw new RuntimeException("Stub!"); }
@java.lang.Deprecated()
public static  void dragQuarterScreenDown(android.test.ActivityInstrumentationTestCase test) { throw new RuntimeException("Stub!"); }
public static  void dragQuarterScreenDown(android.test.InstrumentationTestCase test, android.app.Activity activity) { throw new RuntimeException("Stub!"); }
@java.lang.Deprecated()
public static  void dragQuarterScreenUp(android.test.ActivityInstrumentationTestCase test) { throw new RuntimeException("Stub!"); }
public static  void dragQuarterScreenUp(android.test.InstrumentationTestCase test, android.app.Activity activity) { throw new RuntimeException("Stub!"); }
@java.lang.Deprecated()
public static  void scrollToBottom(android.test.ActivityInstrumentationTestCase test, android.view.ViewGroup v) { throw new RuntimeException("Stub!"); }
public static  void scrollToBottom(android.test.InstrumentationTestCase test, android.app.Activity activity, android.view.ViewGroup v) { throw new RuntimeException("Stub!"); }
@java.lang.Deprecated()
public static  void scrollToTop(android.test.ActivityInstrumentationTestCase test, android.view.ViewGroup v) { throw new RuntimeException("Stub!"); }
public static  void scrollToTop(android.test.InstrumentationTestCase test, android.app.Activity activity, android.view.ViewGroup v) { throw new RuntimeException("Stub!"); }
@java.lang.Deprecated()
public static  void dragViewToBottom(android.test.ActivityInstrumentationTestCase test, android.view.View v) { throw new RuntimeException("Stub!"); }
public static  void dragViewToBottom(android.test.InstrumentationTestCase test, android.app.Activity activity, android.view.View v) { throw new RuntimeException("Stub!"); }
@java.lang.Deprecated()
public static  void dragViewToBottom(android.test.ActivityInstrumentationTestCase test, android.view.View v, int stepCount) { throw new RuntimeException("Stub!"); }
public static  void dragViewToBottom(android.test.InstrumentationTestCase test, android.app.Activity activity, android.view.View v, int stepCount) { throw new RuntimeException("Stub!"); }
public static  void tapView(android.test.InstrumentationTestCase test, android.view.View v) { throw new RuntimeException("Stub!"); }
public static  void touchAndCancelView(android.test.InstrumentationTestCase test, android.view.View v) { throw new RuntimeException("Stub!"); }
public static  void clickView(android.test.InstrumentationTestCase test, android.view.View v) { throw new RuntimeException("Stub!"); }
@java.lang.Deprecated()
public static  void longClickView(android.test.ActivityInstrumentationTestCase test, android.view.View v) { throw new RuntimeException("Stub!"); }
public static  void longClickView(android.test.InstrumentationTestCase test, android.view.View v) { throw new RuntimeException("Stub!"); }
@java.lang.Deprecated()
public static  void dragViewToTop(android.test.ActivityInstrumentationTestCase test, android.view.View v) { throw new RuntimeException("Stub!"); }
@java.lang.Deprecated()
public static  void dragViewToTop(android.test.ActivityInstrumentationTestCase test, android.view.View v, int stepCount) { throw new RuntimeException("Stub!"); }
public static  void dragViewToTop(android.test.InstrumentationTestCase test, android.view.View v) { throw new RuntimeException("Stub!"); }
public static  void dragViewToTop(android.test.InstrumentationTestCase test, android.view.View v, int stepCount) { throw new RuntimeException("Stub!"); }
@java.lang.Deprecated()
public static  int dragViewBy(android.test.ActivityInstrumentationTestCase test, android.view.View v, int gravity, int deltaX, int deltaY) { throw new RuntimeException("Stub!"); }
@java.lang.Deprecated()
public static  int dragViewBy(android.test.InstrumentationTestCase test, android.view.View v, int gravity, int deltaX, int deltaY) { throw new RuntimeException("Stub!"); }
@java.lang.Deprecated()
public static  int dragViewTo(android.test.ActivityInstrumentationTestCase test, android.view.View v, int gravity, int toX, int toY) { throw new RuntimeException("Stub!"); }
public static  int dragViewTo(android.test.InstrumentationTestCase test, android.view.View v, int gravity, int toX, int toY) { throw new RuntimeException("Stub!"); }
@java.lang.Deprecated()
public static  int dragViewToX(android.test.ActivityInstrumentationTestCase test, android.view.View v, int gravity, int toX) { throw new RuntimeException("Stub!"); }
public static  int dragViewToX(android.test.InstrumentationTestCase test, android.view.View v, int gravity, int toX) { throw new RuntimeException("Stub!"); }
@java.lang.Deprecated()
public static  int dragViewToY(android.test.ActivityInstrumentationTestCase test, android.view.View v, int gravity, int toY) { throw new RuntimeException("Stub!"); }
public static  int dragViewToY(android.test.InstrumentationTestCase test, android.view.View v, int gravity, int toY) { throw new RuntimeException("Stub!"); }
@java.lang.Deprecated()
public static  void drag(android.test.ActivityInstrumentationTestCase test, float fromX, float toX, float fromY, float toY, int stepCount) { throw new RuntimeException("Stub!"); }
public static  void drag(android.test.InstrumentationTestCase test, float fromX, float toX, float fromY, float toY, int stepCount) { throw new RuntimeException("Stub!"); }
}
